@@ -1,3 +1,6 @@
+#[macro_use]
+extern crate version;
+
 mod app;
 mod command;
 mod config;
