@@ -11,11 +11,11 @@ pub fn get(client: &Arc<Client>) -> Result<(), CliError> {
         .map_err(|_err| CliError::AccountNotFound(health_addr.to_string()))?;
     let health_data = cronos_sdk::account::Health::try_from(data)
         .map_err(|_err| CliError::AccountDataNotParsable(health_addr.to_string()))?;
-    let blocktime =
-        cronos_sdk::blocktime(client).map_err(|err| CliError::BadClient(err.to_string()))?;
+    let ts =
+        cronos_sdk::clock::get_time(client).map_err(|err| CliError::BadClient(err.to_string()))?;
 
-    println!("  Block time: {}", blocktime);
-    println!("   Last ping: {} sec", blocktime - health_data.last_ping);
-    println!("Recurr drift: {} sec", blocktime - health_data.target_ping);
+    println!("  Block time: {}", ts);
+    println!("   Last ping: {} sec", ts - health_data.last_ping);
+    println!("Recurr drift: {} sec", ts - health_data.target_ping);
     Ok(())
 }
