@@ -27,9 +27,8 @@ pub fn new(
     let config_addr = Config::pda().0;
     let exec_at = match exec_at {
         Some(v) => v,
-        None => {
-            cronos_sdk::blocktime(client).map_err(|err| CliError::BadClient(err.to_string()))?
-        }
+        None => cronos_sdk::clock::get_time(client)
+            .map_err(|err| CliError::BadClient(err.to_string()))?,
     };
     let recurr = match recurr {
         Some(v) => v,
@@ -48,7 +47,7 @@ pub fn new(
     let schedule = cronos_sdk::account::TaskSchedule {
         exec_at,
         stop_at,
-        recurr
+        recurr,
     };
     let task_ix = cronos_sdk::instruction::task_create(
         task_pda,
@@ -56,7 +55,7 @@ pub fn new(
         daemon_addr,
         owner,
         ix,
-        schedule
+        schedule,
     );
 
     // Sign and submit
